@@ -108,6 +108,8 @@ class ConnectionPageBin(Adw.Bin):
         self.connection_page_nav_view.pop_to_tag("connection-page")
         self.region_selection.set_selected(0)
 
+        self.message_parser.reset_connection_timeout()
+
         return GLib.SOURCE_REMOVE
 
     def find_ble_row_by_address(self, address):
@@ -286,6 +288,8 @@ class ConnectionPageBin(Adw.Bin):
             self.logger.warning("no interface")
             return GLib.SOURCE_REMOVE
 
+        self.message_parser.start_connection_timeout()
+
         self.set_connected_button_sensitivity(True)
         notification._withdraw_lost_connection_notification()
 
@@ -370,6 +374,14 @@ class ConnectionPageBin(Adw.Bin):
         self._tcp_connect_async(callback=self._tcp_connect_finish)
         self.set_disconnect_button_sensitivity(False)
 
+    @Gtk.Template.Callback()
+    def _default_tcp_entry_button_clicked_cb(self, button):
+        app = Gtk.Application.get_default()
+
+        url_to_connect = self.connect_tcp_entry.get_text()
+        self.logger.debug("Setting: " + url_to_connect + " to default")
+        app.app_settings.set_default_url(url_to_connect)
+
     @Gtk.Template.Callback()
     def _refresh_serial_ports_clicked_cb(self, button):
         ports = meshtastic.util.findPorts(True)
@@ -638,3 +650,6 @@ class ConnectionPageBin(Adw.Bin):
         #Do this first
         self.message_parser = message_parser.MessageParser()
         self._refresh_serial_ports_clicked_cb(self.refresh_serial_ports_button)
+        url_to_connect = app.app_settings.get_default_url()
+        self.logger.debug("Default url is: " + url_to_connect)
+        self.connect_tcp_entry.set_text(url_to_connect)
