@@ -27,6 +27,9 @@ import hashlib
 import sqlite3
 from datetime import datetime, timezone
 
+import meshtastic
+from meshtastic import BROADCAST_NUM
+
 import gtk_meshtastic_client.utils as utils
 import gtk_meshtastic_client.message_row as message_row
 import gtk_meshtastic_client.chat_page as chat_page
@@ -74,7 +77,7 @@ def find_node_by_id(num, list_box, list_box_children):
 class MessageStorage():
 
     database_name = 'invalid'
-    version = 0
+    version = 1
     load_limit = 20
 
     def update_favorite_node(self, node_row):
@@ -243,16 +246,23 @@ class MessageStorage():
     def load_messages(self, nav_page, channel_id, offset):
         con = sqlite3.connect(self.database_name)
         cur = con.cursor()
-        #Table text_messages(msg_id, from_id, from_short_name, from_long_name, to_id, direction, text, time, delivered, channel_title)
+        #Table text_messages(msg_id, from_id, from_short_name, from_long_name, to_id, direction, text, time, delivered, channel_title, pki_encrypted)
         for row in cur.execute("SELECT * FROM text_messages WHERE channel_title = ? ORDER BY time DESC LIMIT ? OFFSET ?", (channel_id, self.load_limit, offset, )):
             chat_row = message_row.MessageRow()
             chat_row.set_message_id(row[0])
             chat_row.set_short_name(row[2])
             chat_row.set_long_name(row[3])
+
+            if row[4] == meshtastic.BROADCAST_NUM:
+                chat_row.set_direct_message(False)
+            else:
+                chat_row.set_direct_message(True)
+
             chat_row.set_message_direction(row[5])
             chat_row.set_message_content(row[6])
-            chat_row.set_date(row[7])
+            chat_row.update_pki_encryption(row[10])
             chat_row.update_delivery(row[8])
+            chat_row.set_date(row[7])
 
             nav_page.add_message(chat_row)
 
@@ -285,7 +295,7 @@ class MessageStorage():
         if 'channel_id' in locals():
             return channel_id
 
-    def add_sent_message_to_database(self, packet, interface, from_id, short_name, long_name, unix_timestamp, to_address, message_text, channel_id):
+    def add_sent_message_to_database(self, packet, interface, from_id, short_name, long_name, unix_timestamp, to_address, message_text, channel_id, pki_encrypted):
         con = sqlite3.connect(self.database_name)
         cur = con.cursor()
         new_message = []
@@ -311,13 +321,15 @@ class MessageStorage():
         new_message.append(False)
         #channel_Title
         new_message.append(channel_id)
+        #pki_encrypted
+        new_message.append(pki_encrypted)
 
-        cur.execute("INSERT INTO text_messages VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", new_message)
+        cur.execute("INSERT INTO text_messages VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", new_message)
         con.commit()
         cur.close()
         con.close()
 
-    def add_received_message_to_database(self, packet, interface, short_name, long_name, channel_id):
+    def add_received_message_to_database(self, packet, interface, short_name, long_name, channel_id, pki_encryption):
         con = sqlite3.connect(self.database_name)
         cur = con.cursor()
         new_message = []
@@ -352,9 +364,10 @@ class MessageStorage():
         new_message.append(False)
         #channel_Title
         new_message.append(channel_id)
+        #pki_encrypted
+        new_message.append(pki_encryption)
 
-
-        cur.execute("INSERT INTO text_messages VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", new_message)
+        cur.execute("INSERT INTO text_messages VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", new_message)
         con.commit()
         cur.close()
         con.close()
@@ -478,20 +491,34 @@ class MessageStorage():
         self.logger = app.logger
 
         node_id = utils.idToHex(interface.myInfo.my_node_num)
+        self.database_name_v0 = utils.meshtastic_config_dir + '/' + node_id + '_messages_v0.db'
         self.database_name = utils.meshtastic_config_dir + '/' + node_id + '_messages_v' + str(self.version) + '.db'
+        #We did breaking changes to the database, so move it to v1
+        if os.path.exists(self.database_name_v0):
+            self.logger.debug("Found old database version, upgrading")
+            os.rename(self.database_name_v0, self.database_name)
 
         #if the database doesn't exist, create new table
         if not os.path.exists(self.database_name):
             self.logger.debug("Creating new database")
             con = sqlite3.connect(self.database_name)
             cur = con.cursor()
-            cur.execute("CREATE TABLE text_messages(msg_id, from_id, from_short_name, from_long_name, to_id, direction, text, time, delivered, channel_title)")
+            cur.execute("CREATE TABLE text_messages(msg_id, from_id, from_short_name, from_long_name, to_id, direction, text, time, delivered, channel_title, pki_encrypted)")
             con.commit()
             cur.close()
             con.close()
 
         con = sqlite3.connect(self.database_name)
         cur = con.cursor()
+
+        # If the encryption column doesn't exist, none of the DMs were encrypted
+        # We can update other channels later
+        try:
+            cur.execute("SELECT pki_encrypted FROM text_messages")
+        except:
+            cur.execute("ALTER TABLE text_messages ADD pki_encrypted")
+            cur.execute("UPDATE text_messages SET pki_encrypted = 0")
+
         res = cur.execute("SELECT name FROM sqlite_master WHERE name='direct_message_list'")
         result = res.fetchone()
 
