@@ -116,6 +116,8 @@ class NodeRow(Adw.ExpanderRow):
     isLicensed = False
     own_node = False
     favorited = False
+    # "MA==" is the default, indicating there is no public key
+    # It is the base64 equivalent of Hex 0x00
     publicKey = "MA=="
 
     def set_own_node(self, own_node):
@@ -191,7 +193,7 @@ class NodeRow(Adw.ExpanderRow):
             hop_string = "\n\u25CF" + "-" + "\u25CF"
 
         # Set the SNR label with the SNR value and signal strength bars based on https://sensing-labs.com/f-a-q/a-good-radio-level/
-        if hasattr(self, 'snr') and hasattr(self, 'rssi'):
+        if hasattr(self, 'snr') and hasattr(self, 'rssi') and not hasattr(self, 'hopsAway'):
             if self.snr >= -7 and self.rssi >= -115:
                 signal_strength_bars = "████"  # 4 filled bars (strong signal)
             elif self.snr >= -7 and self.rssi >= -126 or self.snr >= -15 and self.rssi >= -115 or self.snr >= -15 and self.rssi >= -126 and self.rssi >= -115 + (self.snr + 15) * -1 * (115 - 126) / (7 - 15):
@@ -313,7 +315,10 @@ class NodeRow(Adw.ExpanderRow):
             self.marker.set_location(self.latitude, self.longitude)
             if self.own_node:
                 win.maps_page_bin.goto_map_first_load(self.latitude, self.longitude)
-                win.maps_page_bin.load_own_node_lat_long(self.latitude, self.longitude, self.altitude)
+                if hasattr(self, 'altitude'):
+                    win.maps_page_bin.load_own_node_lat_long(self.latitude, self.longitude, self.altitude)
+                else:
+                    win.maps_page_bin.load_own_node_lat_long(self.latitude, self.longitude, 0)
             else:
                 win.maps_page_bin.define_longitude_last_seen(self.longitude)
                 win.maps_page_bin.define_latitude_last_seen(self.latitude)
@@ -341,12 +346,21 @@ class NodeRow(Adw.ExpanderRow):
 
         if node.get('snr'):
             self.snr = node["snr"]
+        elif hasattr(self, 'snr'):
+            delattr(self, "snr")
+
+        if node.get('rxRssi'):
+            self.rssi = packet["rxRssi"]
+        elif hasattr(self, 'rssi'):
+            delattr(self, "rssi")
 
         if node.get('lastHeard'):
             self.lastHeard = node["lastHeard"]
 
         if node.get('hopsAway'):
             self.hopsAway = node["hopsAway"]
+        elif hasattr(self, 'hopsAway'):
+            delattr(self, "hopsAway")
 
         if node.get('deviceMetrics'):
             self.deviceMetricPresent = True
@@ -416,9 +430,13 @@ class NodeRow(Adw.ExpanderRow):
 
         if "rxSnr" in packet:
             self.snr = packet["rxSnr"]
+        elif hasattr(self, 'snr'):
+            delattr(self, "snr")
 
         if "rxRssi" in packet:
             self.rssi = packet["rxRssi"]
+        elif hasattr(self, 'rssi'):
+            delattr(self, "rssi")
 
         if 'decoded' in packet:
             if packet['decoded'].get('portnum') == 'NODEINFO_APP':
@@ -444,6 +462,8 @@ class NodeRow(Adw.ExpanderRow):
 
                 if 'hopsAway' in packet:
                     self.hopsAway = packet["hopsAway"]
+                elif hasattr(self, 'hopsAway'):
+                    delattr(self, "hopsAway")
 
                 win.connection_page_bin.database.update_direct_message_chat(self)
                 if self.favorited:
@@ -594,6 +614,21 @@ class NodeRow(Adw.ExpanderRow):
 
         win.nearby_nodes_page_bin.nearby_nodes_list_box.invalidate_sort()
 
+    def show_map_cb(self) -> bool:
+        app = Gtk.Application.get_default()
+        win = Gtk.Application.get_active_window(app)
+
+        win.window_stack.set_visible_child_name("map")
+        win.maps_page_bin.goto_map(self.latitude, self.longitude, 14)
+        return GLib.SOURCE_REMOVE
+
+    @Gtk.Template.Callback()
+    def _map_button_clicked_cb(self, button):
+        if hasattr(self, 'latitude') and hasattr(self, 'longitude'):
+            GLib.timeout_add(200, self.show_map_cb)
+        else:
+            self.logger.warning("No lat and Long to go to")
+
     @Gtk.Template.Callback()
     def _favorite_button_clicked_cb(self, button):
         self.toggle_favorite_node(True)
@@ -603,6 +638,7 @@ class NodeRow(Adw.ExpanderRow):
         app = Gtk.Application.get_default()
 
         self.logger = app.logger
+        self.set_use_markup(False)
 
         secondary_button_gesture = Gtk.GestureClick(button=Gdk.BUTTON_SECONDARY)
         secondary_button_gesture.connect("released", self.right_clicked_cb, secondary_button_gesture)
