@@ -61,6 +61,13 @@ class SettingsObject(GObject.GObject):
     def get_quit_if_connected(self):
         return self._settings.get_boolean("quit-if-connected")
 
+    def set_default_url(self, default_url):
+        return self._settings.set_string("default-url", default_url)
+        self._settings.apply()
+
+    def get_default_url(self):
+        return self._settings.get_string("default-url")
+
     def __init__(self, project_rdnn_name, **kwargs):
         super().__init__(**kwargs)
         app = Gtk.Application.get_default()
